.. aiocometd documentation master file, created by
   sphinx-quickstart on Fri Mar 30 13:11:46 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../../DESCRIPTION.rst

Contents
--------

.. toctree::
    :maxdepth: 3

    guide
    api
    changes

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. include:: global.rst
